# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.2] - 2025-12-18

### Added

- Add GitHub Actions CI and release workflows
- Rename package to dark-madr for PyPI

### Changed

- Use uv for build and publish instead of twine

### Miscellaneous Tasks

- Update URLs after repo rename to dark-madr
